@@ -18,37 +18,46 @@ from mpl_toolkits.mplot3d import Axes3D
 
 # documentation for all functions and commands:
 def docs():
+
+    # print abstract:
     print(
         "[1] ssap.info()\n"
         "[2] ssap.docs()\n"
-        "[3] ssap.bsfcmap(speed,torque,bsfc,title,level)"
-        "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,title)"
-        
-        "--------------------------------------------------------------------"
-        "[Details]:"
-        "[1] ssap.info() - SSAP python package description;\n"
-        
-        "[2] ssap.docs() - All function modules and commands in SSAP package;\n"
-        
-        "[3] ssap.bsfcmap(speed,torque,bsfc,title,level) - ICE bsfcmap chart\n"
-        "\t ● speed:engine speed\n"
-        "\t ● torque:engine torque\n"
-        "\t ● bsfc:engine bfsc\n"
-        "\t ● title:create a name for your chart\n"
-        "\t ● level: bsfcmap boundary level matrix, define graininess for your map.\n"
-        
-        "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,title) - ICE duty cycle chart\n"
-        "\t ● speed:engine speed\n"
-        "\t ● torque:engine torque\n"
-        "\t ● x1:speed start point\n"
-        "\t ● x2:speed end point\n"
-        "\t ● stepx:speed gap distance\n"
-        "\t ● y1:torque start point\n"
-        "\t ● y2:torque end point\n"
-        "\t ● stepy:torque gap distance\n"
-        "\t ● title:create a name for your chart\n"
+        "[3] ssap.bsfcmap(speed,torque,bsfc,title,level)\n"
+        "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,title)\n"
+        "[5] ssap.dutycycle3d(speed,torque,colnum,title)\n"
+        "[6] ssap.boxplot01(x,label,title)\n"
     )
 
+    # explain details:
+    # print(
+    #     "--------------------------------------------------------------------\n"
+    #     "[Details]:\n"
+    #     "[1] ssap.info() - SSAP python package description;\n"
+    #
+    #     "[2] ssap.docs() - All function modules and commands in SSAP package;\n"
+    #
+    #     "[3] ssap.bsfcmap(speed,torque,bsfc,title,level) - ICE bsfcmap chart\n"
+    #     "\t ● speed:engine speed\n"
+    #     "\t ● torque:engine torque\n"
+    #     "\t ● bsfc:engine bfsc\n"
+    #     "\t ● title:create a name for your chart\n"
+    #     "\t ● level: bsfcmap boundary level matrix, define graininess for your map.\n"
+    #
+    #     "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,title) - ICE duty cycle chart\n"
+    #     "\t ● speed:engine speed\n"
+    #     "\t ● torque:engine torque\n"
+    #     "\t ● x1:speed start point\n"
+    #     "\t ● x2:speed end point\n"
+    #     "\t ● stepx:speed gap distance\n"
+    #     "\t ● y1:torque start point\n"
+    #     "\t ● y2:torque end point\n"
+    #     "\t ● stepy:torque gap distance\n"
+    #     "\t ● title:create a name for your chart\n"
+    #
+    #     "[5] ..."
+    # )
+
 
 # links
 def link():
@@ -61,14 +70,12 @@ def link():
         "[6] pypi step2 | twine upload dist/*\n"
     )
 
-
 # basic introduction
 def info():
     print('Welcome to SSAP! SSAP→[Self Service Analytics Platform]. There are different analytics function modules to '
           'support you complete different data analytics scenarios. Please enjoy! Any question or support needed, '
           'please raise in Big Data Community(BDC).')
 
-
 # bsfcmap | 20.dec.09
 def bsfcmap(speed, torque, bsfc, title, level):
     x = np.array(speed)
@@ -163,5 +170,40 @@ def dutycycle3d(speed, torque, colnum, title):
     ax.set_title(title)
     plt.show()
 
+# boxplot01 (single boxplot, 1 parameter, details info) | 20.dec.14
+def boxplot01(x,label,title):
+    import matplotlib.pyplot as plt
+    import pandas as pd
 
+    # data = pd.read_csv('demo.csv')
+    fig1, ax1 = plt.subplots()
+    ax1.set_title(title)
+    labels = [label]
 
+    red_square = dict(markerfacecolor='red', marker='o',alpha=0.5,lw=1)
+    B = ax1.boxplot(x,labels = labels, flierprops=red_square)
+    # B = B.set(color='blue')
+    x = [item.get_ydata() for item in B['whiskers']]
+
+    # box_bdr=[]
+    x1 = x[0][1]
+    x2 = x[0][0]
+    x3 = round(np.median(x),2)
+    x4 = x[1][0]
+    x5 = x[1][1]
+
+    box_bdr = [x1,x2,x3,x4,x5]
+
+    for i in range(len(box_bdr)):
+        plt.axhline(y=box_bdr[i],ls = '--',alpha=0.5,c='darkorange',lw=1)
+        plt.text(0.51,box_bdr[i],str(round(box_bdr[i],2)),size=9,c='darkorange')
+
+    # show mean and variation
+    mean = round(np.mean(x))
+    std_error = round(np.std(x))
+    plt.axhline(y=mean,ls = '--',alpha=0.5,c='blue',lw=1)
+    plt.text(1.1,mean,'→ (mean:'+str(mean)+' | std-err:'+str(std_error)+')',size=9,c='blue')
+
+    plt.show()
+
+# boxplot02 (multiple boxplot)
\ No newline at end of file
